@@ -12,11 +12,11 @@
 
 #include <stdlib.h> // for RAND_MAX
 
-#include <klocalizedstring.h>
-#include <krandom.h>
+#include <KLocalizedString>
+#include <KRandom>
 
-#include <qfile.h>
-#include <qfileinfo.h>
+#include <QFile>
+#include <QFileInfo>
 
 #include "division.h"
 
@@ -34,8 +34,10 @@ KGmap::~KGmap()
 bool KGmap::addDivision(division *d)
 {
 	bool b;
-	if ( ( getDivision(d -> getName()) == NULL && getDivision(d -> getRGB()) == NULL ) || 
-	     ( getDivision(d -> getName()) != NULL && getDivision(d -> getRGB()) == NULL && !d->canAsk(division::eClick) && !getDivision(d -> getName())->canAsk(division::eClick) ) )
+	const division *divByName = getDivision(d -> getUntranslatedName());
+	const division *divByColor = getDivision(d -> getRGB());
+	if ( ( divByName == NULL && divByColor == NULL ) || 
+	     ( divByName != NULL && divByColor == NULL && !d->canAsk(division::eClick) && !divByName->canAsk(division::eClick) ) )
 	{
 		p_divisions.append(d);
 		b = true;
@@ -100,39 +102,26 @@ uint KGmap::count(division::askMode am) const
 	return count;
 }
 
-QString KGmap::getDivisionFlagFile(const QString &s) const
+KLocalizedString KGmap::getCapitalToDivisionQuestionPattern() const
 {
-	return getDivision(s) -> getFlagFile();
+	return ki18nc("@title:group", p_capitalToDivisionPattern.toUtf8());
 }
 
-QString KGmap::getDivisionCapital(const QString &s) const
+KLocalizedString KGmap::getDivisionToCapitalQuestionPattern() const
 {
-	return getDivision(s) -> getCapital();
-}
-
-QStringList KGmap::getDivisionFalseCapitals(const QString &divisionName) const
-{
-	return getDivision(divisionName) -> getFalseCapitals();
-}
-
-QString KGmap::getCapitalToDivisionQuestionPattern() const
-{
-	return p_capitalToDivisionPattern;
-}
-
-QString KGmap::getDivisionToCapitalQuestionPattern() const
-{
-	return p_divisionToCapitalPattern;
+	return ki18nc("@title:group", p_divisionToCapitalPattern.toUtf8());
 }
 
 QString KGmap::getCapitalToDivisionTitle() const
 {
-	return p_capitalToDivisionTitle;
+	if (p_capitalToDivisionTitle.isNull()) return i18n("%1 by Capital", getDivisionsString());
+	else return p_capitalToDivisionTitle;
 }
 
 QString KGmap::getDivisionToCapitalTitle() const
 {
-	return p_divisionToCapitalTitle;
+	if (p_divisionToCapitalTitle.isNull()) return i18n("Capitals of %1", getDivisionsString());
+	else return p_divisionToCapitalTitle;
 }
 
 QString KGmap::getFile() const
@@ -162,12 +151,12 @@ QString KGmap::getDivisionsString() const
 	else return p_divisionsString;
 }
 
-QString KGmap::getRandomDivision(division::askMode am) const
+division *KGmap::getRandomDivision(division::askMode am) const
 {
 	QList<division*> aux;
 	int i = (int)((float)p_divisions.size() * KRandom::random() / (RAND_MAX + 1.0));
 	if (!p_divisions[i] -> canAsk(am)) return getRandomDivision(am);
-	else return p_divisions[i] -> getName();
+	else return p_divisions[i];
 }
 
 QString KGmap::getWhatIs(QRgb c, bool all) const
@@ -177,8 +166,8 @@ QString KGmap::getWhatIs(QRgb c, bool all) const
 	if (d == NULL) return QStringLiteral("nothing");
 	else
 	{
-		if (all) return d -> getName();
-		else if (d -> canAsk(division::eClick)) return d -> getName();
+		if (all) return d -> getUntranslatedName();
+		else if (d -> canAsk(division::eClick)) return d -> getUntranslatedName();
 		else return QLatin1String("");
 	}
 }
@@ -214,7 +203,7 @@ division *KGmap::getDivision(const QString &divisionName) const
 {
 	foreach (division* div, p_divisions)
 	{
-		if (div->getName() == divisionName) return div;
+		if (div->getUntranslatedName() == divisionName) return div;
 	}
 	return NULL;
 }
@@ -227,8 +216,3 @@ division *KGmap::getDivision(QRgb c) const
 	}
 	return NULL;
 }
-
-bool KGmap::getDivisionCanAsk(const QString &div, division::askMode am) const
-{
-	return getDivision(div) -> canAsk(am);
-}
